@@ -13,14 +13,13 @@ except:
 
 discovery = "https://discovery.data.storemesh.com"
 
-base_discovery_api = "https://api.discovery.data.storemesh.com"
-# base_discovery_api = "http://192.168.24.207:8000"
-discovery_api = f"{base_discovery_api}/api/v2"
+_base_discovery_api = "https://api.discovery.data.storemesh.com"
+_internal_base_discovery_api = "http://backend:8000"
 
-base_minio_url="s3.minio.data.storemesh.com"
-# base_minio_url="192.168.24.207:9000"
+_external_api_minio = os.environ.get('external_api_minio',"")
+_internal_api_minio = os.environ.get('internal_api_minio',"")
 
-minio_url=f"https://{base_minio_url}"
+_base_minio_url=os.environ.get('base_minio_url')
 bucket_name = 'dataplatform'
 
 class Base:
@@ -30,6 +29,15 @@ class Base:
         Args:
             jwt_token (str): JWT token from IaM.
         """
+        
+        _internal = os.environ.get('internal', None) == "true"
+        self._internal = _internal
+        if self._internal:
+            base_discovery_api = _internal_base_discovery_api
+        else:
+            base_discovery_api = _base_discovery_api
+        self._discovery_api = f"{base_discovery_api}/api/v2"
+        
         if token is None:
             print(f"Please get token from {discovery}")
             token = input("Your Token : ")
@@ -55,30 +63,31 @@ class Base:
         self._minio_access = data['access']
         self._minio_secret = data['secret']
         
-        # self.client = Minio(
-        #     base_minio_url,
-        #     access_key=self._minio_access,
-        #     secret_key=self._minio_secret,
-        #     secure=True
-        # )
-        # self._storage_options = {
-        #     'key': self._minio_access,
-        #     'secret': self._minio_secret,
-        #     'client_kwargs':{
-        #         'endpoint_url': minio_url
-        #     }
-        # }
         self.client = Minio(
-            "192.168.24.207:9000",
+            _base_minio_url,
             access_key=self._minio_access,
             secret_key=self._minio_secret,
             secure=False
         )
-        
+        _scheme = "http" if self._internal else "https"
         self._storage_options = {
             'key': self._minio_access,
             'secret': self._minio_secret,
             'client_kwargs':{
-                'endpoint_url': "http://192.168.24.207:9000"
+                'endpoint_url': f"{_scheme}://{_base_minio_url}"
             }
-        }
\ No newline at end of file
+        }
+        
+    def _replace_minio_api(self, url):
+        return url.replace('https', 'http').replace(_external_api_minio, _internal_api_minio)
+    
+    def _check_fileExists(self, directory, name):
+        _res = requests.get(f"{self._discovery_api}/directory/{directory}/fileExists/?filename={name}", headers=self._jwt_header)
+        if _res.status_code == 200:
+            replace = False
+        elif _res.status_code == 302:
+            replace = input(f"File {name} alrady exists, do you want to replace y/n : ").replace(' ', '').lower() == "y"
+        else:
+            status = _res.json() if _res.status_code < 500 else ""
+            raise Exception(f"check file exists error {status}")
+        return replace
\ No newline at end of file
