@@ -1,9 +1,10 @@
 import requests
 import pandas as pd
 import dask.dataframe as dd
-from .base import discovery_api, bucket_name, minio_url, Base
+from .base import bucket_name, Base
 from .dataset import DatasetManager
 import io
+import time
 
 def append_slash(txt):
     if txt[-1] != '/':
@@ -22,13 +23,9 @@ class DataNode(DatasetManager):
             description = f"data {name}"
             
         name = f'{name}.parquet'
-        _res = requests.get(f"{discovery_api}/directory/{directory}/fileExists/?filename={name}", headers=self._jwt_header)
-        if _res.status_code == 200:
-            replace = False
-        elif _res.status_code == 302:
-            replace = input(f"File {name} alrady exists, do you want to replace y/n : ").replace(' ', '').lower() == "y"
+        replace = self._check_fileExists(directory, name)
         
-        _res = requests.post(f'{discovery_api}/file/', headers=self._jwt_header,
+        _res = requests.post(f'{self._discovery_api}/file/', headers=self._jwt_header,
                                 json={
                                     "name": name,
                                     "description": description,
@@ -40,7 +37,7 @@ class DataNode(DatasetManager):
         if _res.status_code != 201:
             raise Exception(f"can not create directory in discovery {_res.json()}")
         meta = _res.json()
-        _df_ddf = ddf if type(ddf) != None else df
+        _df_ddf = ddf if ddf != None else df
         _df_ddf.to_parquet(f"s3://{bucket_name}/{meta['key']}",
             storage_options=self._storage_options,
             **kwargs
@@ -48,8 +45,14 @@ class DataNode(DatasetManager):
         
         # create profiling & data dict
         if profiling:
-            requests.get(f"{discovery_api}/file/{meta['id']}/createDatadict/", headers=self._jwt_header)
-            requests.get(f"{discovery_api}/file/{meta['id']}/createProfileling/", headers=self._jwt_header)
+            for _ in range(5):
+                _res = requests.get(f"{self._discovery_api}/file/{meta['id']}/", headers=self._jwt_header)
+                if _res.status_code != 200:
+                    time.sleep(2)
+                else:
+                    break
+            requests.get(f"{self._discovery_api}/file/{meta['id']}/createDatadict/", headers=self._jwt_header)
+            requests.get(f"{self._discovery_api}/file/{meta['id']}/createProfileling/", headers=self._jwt_header)
             
         return {
             'sucess': True,
@@ -58,7 +61,7 @@ class DataNode(DatasetManager):
         }
     
     def get_file(self, file_id=None):
-        _res = requests.get(f"{discovery_api}/file/{file_id}/", headers=self._jwt_header)
+        _res = requests.get(f"{self._discovery_api}/file/{file_id}/", headers=self._jwt_header)
         if _res.status_code != 200:
             txt = _res.json() if _res.status_code < 500 else " "
             raise Exception(f"Some thing wrong, {txt}")
@@ -73,7 +76,7 @@ class DataNode(DatasetManager):
         
     
     def read_ddf(self, file_id=None):
-        _res = requests.get(f"{discovery_api}/file/{file_id}/", headers=self._jwt_header)
+        _res = requests.get(f"{self._discovery_api}/file/{file_id}/", headers=self._jwt_header)
         if _res.status_code != 200:
             txt = _res.json() if _res.status_code < 500 else " "
             raise Exception(f"Some thing wrong, {txt}")
@@ -86,10 +89,10 @@ class DataNode(DatasetManager):
             return dd.read_parquet(f"s3://{bucket_name}/{meta['key']}", storage_options=self._storage_options)
         elif _f_type == "csv":
             return dd.read_csv(f"s3://{bucket_name}/{meta['key']}", storage_options=self._storage_options)
-        return None
+        return Exception(f"Can not read file extension {_f_type}, support [parquet, csv]")
         
     def read_df(self, file_id=None):
-        _res = requests.get(f"{discovery_api}/file/{file_id}/", headers=self._jwt_header)
+        _res = requests.get(f"{self._discovery_api}/file/{file_id}/", headers=self._jwt_header)
         if _res.status_code != 200:
             txt = _res.json() if _res.status_code < 500 else " "
             raise Exception(f"Some thing wrong, {txt}")
@@ -102,4 +105,4 @@ class DataNode(DatasetManager):
             return pd.read_parquet(f"s3://{bucket_name}/{meta['key']}", storage_options=self._storage_options)
         elif _f_type == "csv":
             return pd.read_csv(f"s3://{bucket_name}/{meta['key']}", storage_options=self._storage_options)
-        return None
\ No newline at end of file
+        return Exception(f"Can not read file extension {_f_type}, support [parquet, csv]")
\ No newline at end of file
